NLSL: fpdatum Union Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- Data Types List
- Data Types
- Data Fields

Public Attributes | List of all members
fpdatum Union Reference

## Public Attributes
float | number
char | byte [4]

## Detailed Description

Definition at line 149 of file genio.c.

## Member Data Documentation

char fpdatum::byte[4]

Definition at line 151 of file genio.c.

float fpdatum::number

Definition at line 150 of file genio.c.

The documentation for this union was generated from the following file:

- genio.c